# automesh

[![book](https://img.shields.io/badge/automesh-Book-blue?logo=mdbook&logoColor=000000)](https://autotwin.github.io/automesh)
[![crates](https://img.shields.io/crates/v/automesh?logo=rust&logoColor=000000&label=Crates&color=32592f)](https://crates.io/crates/automesh)
[![docs](https://img.shields.io/badge/Docs-API-e57300?logo=docsdotrs&logoColor=000000)](https://docs.rs/automesh)
[![pypi](https://img.shields.io/pypi/v/automesh?logo=pypi&logoColor=FBE072&label=PyPI&color=4B8BBE)](https://pypi.org/project/automesh)
[![docs](https://img.shields.io/badge/Docs-API-8CA1AF?logo=readthedocs)](https://automesh.readthedocs.io)
[![conda](https://img.shields.io/conda/v/conda-forge/automesh?logo=Anaconda&label=Conda&color=%2344A833)](https://anaconda.org/conda-forge/automesh)
[![DOI](https://img.shields.io/badge/DOI-10.5281/zenodo.13845433-blue)](https://doi.org/10.5281/zenodo.13845433)

Automatic mesh generation.

* [Introduction](https://autotwin.github.io/automesh/introduction.html)
* [Installation](https://autotwin.github.io/automesh/installation.html)
* [Getting Started](https://autotwin.github.io/automesh/getting_started.html)
* [Citation](https://github.com/autotwin/automesh/blob/main/CITATION.cff)
* [License](https://github.com/autotwin/automesh/blob/main/LICENSE)
